RankEval – Analysis and evaluation of Learning-to-Rank models — RankEval 0.00 documentation

# RankEval – Analysis and evaluation of Learning-to-Rank models

RankEval is a Python library for the analysis and evaluation of Learning-to-Rank models based on ensembles of regression trees. Target audience includes the machine learning (ML) and information retrieval (IR) communities.

## Citing RankEval

Please cite:

    @inproceedings{rankeval-sigir17,
      author = {Claudio Lucchese and Cristina Ioana Muntean and Franco Maria Nardini and
                Raffaele Perego and Salvatore Trani},
      title = {RankEval: An Evaluation and Analysis Framework for Learning-to-Rank Solutions},
      booktitle = {SIGIR 2017: Proceedings of the 40th International {ACM} {SIGIR}
                   Conference on Research and Development in Information Retrieval},
      year = {2017},
      location = {Tokyo, Japan}
    }

Contents:

- rankeval package

# Indices and tables

- Index
- Module Index
- Search Page